#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 js-dgtable
version:              0.5.2
visibility:           public
id:                   js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
key:                  js-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
license:              MIT
copyright:            Neil Mitchell 2019
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/js-dgtable#readme
synopsis:             Obtain minified jquery.dgtable code
description:
    This package bundles the minified <https://github.com/danielgindi/jquery.dgtable jquery.dgtable> code into a Haskell package,
    so it can be depended upon by Cabal packages. The first three components of
    the version number match the upstream jquery.dgtable version. The package is designed
    to meet the redistribution requirements of downstream users (e.g. Debian).

category:             Javascript
abi:                  b8ef5b5ce77d5dd34a00ed40689f1590
exposed:              True
exposed-modules:      Language.Javascript.DGTable
hidden-modules:       Paths_js_dgtable
import-dirs:          /usr/lib/ghc-9.6.6/site-local/js-dgtable-0.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/js-dgtable-0.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/js-dgtable-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-js-dgtable
hs-libraries:         HSjs-dgtable-0.5.2-JIjvuPD3we7ByE7r2A7oMM
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-js-dgtable/html/js-dgtable.haddock
haddock-html:         /usr/share/doc/haskell-js-dgtable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

